# -*- coding: utf-8 -*-
from distutils.core import setup

modules = \
['swpy']
setup_kwargs = {
    'name': 'swpy',
    'version': '0.1.2',
    'description': 'A simple, yet useful stopwatch library.',
    'long_description': "# swpy: A simple, yet useful stopwatch library for python\n\n[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/swpy.svg?logo=python&logoColor=white&style=flat-square)](https://pypi.org/project/swpy/)\n[![PyPI](https://img.shields.io/pypi/v/swpy.svg?style=flat-square)](https://pypi.org/project/swpy/)\n[![CircleCI](https://img.shields.io/circleci/project/github/peinan/swpy.svg?logo=circleci&style=flat-square)](https://circleci.com/gh/peinan/swpy/tree/master)\n[![codecov](https://img.shields.io/codecov/c/gh/peinan/swpy.svg?logo=codecov&style=flat-square)](https://codecov.io/gh/peinan/swpy)\n[![PyPI - License](https://img.shields.io/pypi/l/swpy.svg?color=blue&style=flat-square)](https://github.com/peinan/swpy/blob/master/LICENSE)\n\n## Requirements\n\n- Python 3.6+\n\n## Install\n\nJust use pip to install.\n\n```bash\npip install swpy\n```\n\n## Usage\n\n### Basic Usage\n\nImport `Timer` class from `swpy`, and use `with` statement to capsule the block where you want timing.\n\n```python\nfrom swpy import Timer\nfrom time import sleep\n\nwith Timer():\n    sleep(1)\n```\n\nOr use `start()` and `stop()` function to controll the timer.\n\n```python\nt = Timer()\nt.start()\nsleep(1)\nt.stop()\n```\n\nAnd the output will look like below:\n\n```\n[timer-1557406243.3309178] started.\n[timer-1557406243.3309178] finish time: 1.00 sec.\n```\n\n### Features\n\n#### Name the timer\n\nYou can name the timer to make it easy to recognize.\n\n```python\nwith Timer(name='test timer'):\n    sleep(1)\n```\n\nNow the timer is renamed to `test timer` !\n\n```\n[test timer] started.\n[test timer] finish time: 1.00 sec.\n```\n\n#### Lap time and Split time\n\nThere are two types to measuring time without stoping: lap time and split time. The figure below may help you to understand the differences.\n\n![split_lap_time](https://github.com/peinan/swpy/blob/master/imgs/split_lap_time.png)\n\nWe prepared `split` and `lap` functions for this kind of usage. The examples are below.\n\n```python\n# measure split time\nwith Timer('timer') as t:\n    sleep(1)\n    t.split()\n    sleep(1)\n    t.split()\n    sleep(1)\n    t.split()\n```\n\n```\n# outptus\n[timer] started.\n[timer] split time:  1.00 sec.\n[timer] split time:  2.01 sec.\n[timer] split time:  3.01 sec.\n[timer] finish time: 3.01 sec.\n```\n\n```python\n# measure lap time\nwith Timer('timer') as t:\n    sleep(1)\n    t.lap()\n    sleep(1)\n    t.lap()\n    sleep(1)\n    t.lap()\n```\n\n```\n# outputs\n[timer] started.\n[timer] lap time:    1.00 sec.\n[timer] lap time:    1.01 sec.\n[timer] lap time:    1.00 sec.\n[timer] finish time: 3.01 sec.\n```\n\nAnd you can name your lap/split time in the case of measuring several tasks in a single run as below.\n\n```python\nwith Timer('task timer') as t:\n    task1()\n    t.lap('task1')\n    task2()\n    t.lap('task2')\n```\n\n```\n# outputs\n[task timer] started.\n[task timer] [task1] lap time:    3.69 sec.\n[task timer] [task2] lap time:    4.21 sec.\n[task timer] finish time: 7.91 sec.\n```\n\n#### Use your own logger\n\nYou can use your own logger instead of the default `print`.\n\n```python\nfrom logzero import logger\nimport logging\n\nwith Timer(name='test timer', logger=logger, level=logging.DEBUG):\n    sleep(1)\n```\n\nIt will output using logger.\n\n```\n[D 190510 14:41:59 swpy:15] [test timer] started.\n[D 190510 14:42:00 swpy:15] [test timer] finish time: 1.01 sec.\n```\n\n#### Define your own callback\n\nSometimes, we want to do something after the job has done like notifying the result to slack, executing the next process and so on. Callback feature will help you to do those.\n\n```python\n# define a slack notification function\nimport requests, json\ndef send_slack(msg):\n    requests.post(SLACK_URL, json.dumps({'text': msg}))\n\n# just specify the callback argument\nwith Timer(name='experiment-1', callback=send_slack):\n    sleep(1)\n```\n\n## License\n\n[MIT](https://github.com/peinan/swpy/blob/master/LICENSE)\n",
    'author': 'Peinan ZHANG',
    'author_email': 'peinan7@gmail.co.jp',
    'url': 'https://github.com/peinan/swpy',
    'py_modules': modules,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
